@@ -1,3 +1,4 @@
+pub use committed_status::*;
 pub use element::*;
 pub use parse_error::*;
 pub use parse_result::*;
@@ -10,6 +11,7 @@ pub use parser_pure::*;
 pub use parser_runner::*;
 pub use parsers::*;
 
+mod committed_status;
 mod element;
 mod parse_error;
 mod parse_result;
