@@ -1,5 +1,5 @@
-use crate::core::parse_error::ParseError;
 use crate::core::parser_monad::ParserMonad;
+use crate::core::{CommittedStatus, ParseError};
 
 pub trait Parsers {
   type P<'p, I, A>: ParserMonad<'p, Input = I, Output = A>
@@ -25,14 +25,14 @@ pub trait Parsers {
     F: Fn() -> A + 'a,
     A: 'a;
 
-  fn failed<'a, I, A>(value: ParseError<'a, I>, committed: bool) -> Self::P<'a, I, A>
+  fn failed<'a, I, A>(value: ParseError<'a, I>, committed: CommittedStatus) -> Self::P<'a, I, A>
   where
     I: Clone + 'a,
     A: 'a;
 
   fn failed_lazy<'a, I, A, F>(f: F) -> Self::P<'a, I, A>
   where
-    F: Fn() -> (ParseError<'a, I>, bool) + 'a,
+    F: Fn() -> (ParseError<'a, I>, CommittedStatus) + 'a,
     I: 'a,
     A: 'a;
 
